==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_lister_item.js <==
_me = obj_lister_item.prototype;
function obj_lister_item(){};

_me.__constructor = function(){

	//zjistit limit
	storage.library('gw_others');
	this.__list = parseInt(GWOthers.getItem('LAYOUT_SETTINGS','dg_view_limit'));
	if(isNaN(this.__list)) this.__list = 0;
};
/**
 * @param:  oObj  - datgrid object
 *          bServer - type of binding (true - server sort)
 **/
_me._bind = function(oObj){

	//bind lister to DG object
	if (oObj.lister && oObj.lister._pathName != this._pathName)
		oObj.lister._destruct();
	oObj.lister = this;

	//bind DG object to lister
	this.__bind = oObj;
	
    this._value(this.__bind._lastOffset);
};

_me._onchange = function(value){
	if (!this.__bind) return;
		
	//Identifikace folderu
	var aDataSet = dataSet.get(this.__bind._dataSet);
	for(var sAccId in aDataSet)
		for(var sFolId in aDataSet[sAccId])
	  
	//Mme-li zapnuty cookies, ulome nov offset
	if (this.__bind._cookiesEnabled)
		dataSet.add('datagrid_views',[sAccId,sFolId,'offset'],value);

	//client sort
/*
	if (this.__bind._sortLimit >= this.__range){
		//	doslo-li ke zmene poctu zprav (vetsinou pri mazani vedoucimu k prepnuti mezi Server Sort->Client Sort),
		//	dojde k refreshy diky dataset._update
		if (this.__bind._aData.length == this.__range)
			this.__bind.__update();
	}
	//server sort
	else
	{
*/
    	var aLastSort = this.__bind._lastSort;

		//Chceme poloky seazen?
		if (aLastSort)
			this.__bind._serverSort({'aid':sAccId,'fid':sFolId},aLastSort['column'],aLastSort['type']);
		else{
			var aValues = WMItems.default_values(sFolId,dataSet.get('folders',[sAccId,sFolId,'TYPE']));
			WMItems.list({'aid':sAccId,'fid':sFolId,'values':aValues,'filter':{'offset':value,'limit':this.__list}},this.__bind._dataSet);
		}
//	}
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_lister_item.js <==
_me = obj_lister_item.prototype;
function obj_lister_item(){};

_me.__constructor = function(){

	//zjistit limit
	storage.library('gw_others');
    this.__list = GWOthers.getItem('LAYOUT_SETTINGS','dg_view_limit')*1;

	if (!this.__list || isNaN(this.__list)){
        this.__list = 30;
		//this.__list = GWOthers.getDefaultValues('LAYOUT_SETTINGS').DG_VIEW_LIMIT;
	}
};
/**
 * @param:  oObj  - datgrid object
 *          bServer - type of binding (true - server sort)
 **/
_me._bind = function(oObj){

	//bind lister to DG object
	if (oObj.lister && oObj.lister._pathName != this._pathName)
		oObj.lister._destruct();
	oObj.lister = this;

	//bind DG object to lister
	this.__bind = oObj;
	
    this._value(this.__bind._lastOffset);
};

_me._onchange = function(value){
	if (!this.__bind) return;
		
	//Identifikace folderu
	var aDataSet = dataSet.get(this.__bind._dataSet);
	for(var sAccId in aDataSet)
		for(var sFolId in aDataSet[sAccId])
	  
	//Mme-li zapnuty cookies, ulome nov offset
	if (this.__bind._cookiesEnabled)
		dataSet.add('datagrid_views',[sAccId,sFolId,'offset'],value);

	//client sort
/*
	if (this.__bind._sortLimit >= this.__range){
		//	doslo-li ke zmene poctu zprav (vetsinou pri mazani vedoucimu k prepnuti mezi Server Sort->Client Sort),
		//	dojde k refreshy diky dataset._update
		if (this.__bind._aData.length == this.__range)
			this.__bind.__update();
	}
	//server sort
	else
	{
*/
    	var aLastSort = this.__bind._lastSort;

		//Chceme poloky seazen?
		if (aLastSort)
			this.__bind._serverSort({'aid':sAccId,'fid':sFolId},aLastSort['column'],aLastSort['type']);
		else{
			var aValues = WMItems.default_values(dataSet.get('folders',[sAccId,sFolId,'TYPE']));
			WMItems.list({'aid':sAccId,'fid':sFolId,'values':aValues,'filter':{'offset':value,'limit':this.__list}},this.__bind._dataSet);
		}
//	}
};
